@@ -6,7 +6,6 @@
 """
 import json
 import mock
-import os
 import SoftLayer
 
 from SoftLayer.CLI import exceptions
@@ -29,21 +28,17 @@ class DedicatedHostsTests(testing.TestCase):
                              'datacenter': 'dal05',
                              'diskCapacity': 1200,
                              'guestCount': 1,
-                             'id': 44701,
+                             'id': 12345,
                              'memoryCapacity': 242,
-                             'name': 'khnguyendh'
+                             'name': 'test-dedicated'
                          }]
                          )
 
-    def tear_down(self):
-        if os.path.exists("test.txt"):
-            os.remove("test.txt")
-
     def test_details(self):
         mock = self.set_mock('SoftLayer_Virtual_DedicatedHost', 'getObject')
         mock.return_value = SoftLayer_Virtual_DedicatedHost.getObjectById
 
-        result = self.run_command(['dedicatedhost', 'detail', '44701', '--price', '--guests'])
+        result = self.run_command(['dedicatedhost', 'detail', '12345', '--price', '--guests'])
         self.assert_no_fail(result)
 
         self.assertEqual(json.loads(result.output),
@@ -54,19 +49,19 @@ class DedicatedHostsTests(testing.TestCase):
                              'disk capacity': 1200,
                              'guest count': 1,
                              'guests': [{
-                                 'domain': 'Softlayer.com',
-                                 'hostname': 'khnguyenDHI',
-                                 'id': 43546081,
-                                 'uuid': '806a56ec-0383-4c2e-e6a9-7dc89c4b29a2'
+                                 'domain': 'test.com',
+                                 'hostname': 'test-dedicated',
+                                 'id': 12345,
+                                 'uuid': 'F9329795-4220-4B0A-B970-C86B950667FA'
                              }],
-                             'id': 44701,
+                             'id': 12345,
                              'memory capacity': 242,
                              'modify date': '2017-11-06T11:38:20-06:00',
-                             'name': 'khnguyendh',
-                             'owner': '232298_khuong',
+                             'name': 'test-dedicated',
+                             'owner': 'test-dedicated',
                              'price_rate': 1515.556,
                              'router hostname': 'bcr01a.dal05',
-                             'router id': 51218}
+                             'router id': 12345}
                          )
 
     def test_details_no_owner(self):
@@ -85,18 +80,18 @@ class DedicatedHostsTests(testing.TestCase):
                                                      'disk capacity': 1200,
                                                      'guest count': 1,
                                                      'guests': [{
-                                                         'domain': 'Softlayer.com',
-                                                         'hostname': 'khnguyenDHI',
-                                                         'id': 43546081,
-                                                         'uuid': '806a56ec-0383-4c2e-e6a9-7dc89c4b29a2'}],
-                                                     'id': 44701,
+                                                         'domain': 'test.com',
+                                                         'hostname': 'test-dedicated',
+                                                         'id': 12345,
+                                                         'uuid': 'F9329795-4220-4B0A-B970-C86B950667FA'}],
+                                                     'id': 12345,
                                                      'memory capacity': 242,
                                                      'modify date': '2017-11-06T11:38:20-06:00',
-                                                     'name': 'khnguyendh',
+                                                     'name': 'test-dedicated',
                                                      'owner': None,
                                                      'price_rate': 0,
                                                      'router hostname': 'bcr01a.dal05',
-                                                     'router id': 51218}
+                                                     'router id': 12345}
                          )
 
     def test_create_options(self):
@@ -159,29 +154,29 @@ class DedicatedHostsTests(testing.TestCase):
         mock_package_obj.return_value = SoftLayer_Product_Package.getAllObjectsDH
 
         result = self.run_command(['dedicatedhost', 'create',
-                                   '--hostname=host',
-                                   '--domain=example.com',
+                                   '--hostname=test-dedicated',
+                                   '--domain=test.com',
                                    '--datacenter=dal05',
                                    '--flavor=56_CORES_X_242_RAM_X_1_4_TB',
                                    '--billing=hourly'])
         self.assert_no_fail(result)
         args = ({
                     'hardware': [{
-                        'domain': 'example.com',
+                        'domain': 'test.com',
                         'primaryBackendNetworkComponent': {
                             'router': {
-                                'id': 51218
+                                'id': 12345
                             }
                         },
-                        'hostname': 'host'
-                    }],
-                    'prices': [{
-                        'id': 200269
+                        'hostname': 'test-dedicated'
                     }],
+                    'useHourlyPricing': True,
                     'location': 'DALLAS05',
                     'packageId': 813,
                     'complexType': 'SoftLayer_Container_Product_Order_Virtual_DedicatedHost',
-                    'useHourlyPricing': True,
+                    'prices': [{
+                        'id': 200269
+                    }],
                     'quantity': 1},)
 
         self.assert_called_with('SoftLayer_Product_Order', 'placeOrder',
@@ -195,21 +190,21 @@ class DedicatedHostsTests(testing.TestCase):
         mock_package_obj.return_value = SoftLayer_Product_Package.getAllObjectsDHGpu
 
         result = self.run_command(['dedicatedhost', 'create',
-                                   '--hostname=host',
-                                   '--domain=example.com',
+                                   '--hostname=test-dedicated',
+                                   '--domain=test.com',
                                    '--datacenter=dal05',
                                    '--flavor=56_CORES_X_484_RAM_X_1_5_TB_X_2_GPU_P100',
                                    '--billing=hourly'])
         self.assert_no_fail(result)
         args = ({
                     'hardware': [{
-                        'domain': 'example.com',
+                        'domain': 'test.com',
                         'primaryBackendNetworkComponent': {
                             'router': {
-                                'id': 51218
+                                'id': 12345
                             }
                         },
-                        'hostname': 'host'
+                        'hostname': 'test-dedicated'
                     }],
                     'prices': [{
                         'id': 200269
@@ -233,8 +228,8 @@ class DedicatedHostsTests(testing.TestCase):
 
         result = self.run_command(['dedicatedhost', 'create',
                                    '--verify',
-                                   '--hostname=host',
-                                   '--domain=example.com',
+                                   '--hostname=test-dedicated',
+                                   '--domain=test.com',
                                    '--datacenter=dal05',
                                    '--flavor=56_CORES_X_242_RAM_X_1_4_TB',
                                    '--billing=hourly'])
@@ -244,12 +239,12 @@ class DedicatedHostsTests(testing.TestCase):
                     'useHourlyPricing': True,
                     'hardware': [{
 
-                        'hostname': 'host',
-                        'domain': 'example.com',
+                        'hostname': 'test-dedicated',
+                        'domain': 'test.com',
 
                         'primaryBackendNetworkComponent': {
                             'router': {
-                                'id': 51218
+                                'id': 12345
                             }
                         }
                     }],
@@ -263,8 +258,8 @@ class DedicatedHostsTests(testing.TestCase):
 
         result = self.run_command(['dh', 'create',
                                    '--verify',
-                                   '--hostname=host',
-                                   '--domain=example.com',
+                                   '--hostname=test-dedicated',
+                                   '--domain=test.com',
                                    '--datacenter=dal05',
                                    '--flavor=56_CORES_X_242_RAM_X_1_4_TB',
                                    '--billing=monthly'])
@@ -273,11 +268,11 @@ class DedicatedHostsTests(testing.TestCase):
         args = ({
                     'useHourlyPricing': True,
                     'hardware': [{
-                        'hostname': 'host',
-                        'domain': 'example.com',
+                        'hostname': 'test-dedicated',
+                        'domain': 'test.com',
                         'primaryBackendNetworkComponent': {
                             'router': {
-                                'id': 51218
+                                'id': 12345
                             }
                         }
                     }],
@@ -296,8 +291,8 @@ class DedicatedHostsTests(testing.TestCase):
         mock_package_obj.return_value = SoftLayer_Product_Package.getAllObjectsDH
 
         result = self.run_command(['dh', 'create',
-                                   '--hostname=host',
-                                   '--domain=example.com',
+                                   '--hostname=test-dedicated',
+                                   '--domain=test.com',
                                    '--datacenter=dal05',
                                    '--flavor=56_CORES_X_242_RAM_X_1_4_TB',
                                    '--billing=monthly'])
@@ -305,23 +300,6 @@ class DedicatedHostsTests(testing.TestCase):
         self.assertEqual(result.exit_code, 2)
         self.assertIsInstance(result.exception, exceptions.CLIAbort)
 
-    def test_create_export(self):
-        mock_package_obj = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
-        mock_package_obj.return_value = SoftLayer_Product_Package.getAllObjectsDH
-        mock_package = self.set_mock('SoftLayer_Product_Order', 'verifyOrder')
-        mock_package.return_value = SoftLayer_Product_Package.verifyOrderDH
-
-        self.run_command(['dedicatedhost', 'create',
-                          '--verify',
-                          '--hostname=host',
-                          '--domain=example.com',
-                          '--datacenter=dal05',
-                          '--flavor=56_CORES_X_242_RAM_X_1_4_TB',
-                          '--billing=hourly',
-                          '--export=test.txt'])
-
-        self.assertEqual(os.path.exists("test.txt"), True)
-
     def test_create_verify_no_price_or_more_than_one(self):
         mock_package_obj = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock_package_obj.return_value = SoftLayer_Product_Package.getAllObjectsDH
@@ -332,8 +310,8 @@ class DedicatedHostsTests(testing.TestCase):
 
         result = self.run_command(['dedicatedhost', 'create',
                                    '--verify',
-                                   '--hostname=host',
-                                   '--domain=example.com',
+                                   '--hostname=test-dedicated',
+                                   '--domain=test.com',
                                    '--datacenter=dal05',
                                    '--flavor=56_CORES_X_242_RAM_X_1_4_TB',
                                    '--billing=hourly'])
@@ -341,13 +319,13 @@ class DedicatedHostsTests(testing.TestCase):
         self.assertIsInstance(result.exception, exceptions.ArgumentError)
         args = ({
                     'hardware': [{
-                        'domain': 'example.com',
+                        'domain': 'test.com',
                         'primaryBackendNetworkComponent': {
                             'router': {
-                                'id': 51218
+                                'id': 12345
                             }
                         },
-                        'hostname': 'host'
+                        'hostname': 'test-dedicated'
                     }],
                     'prices': [{
                         'id': 200269
